# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['odherogrid', 'odherogrid.cli']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0',
 'httpx>=0.11.1,<0.12.0',
 'pyyaml>=5.2,<6.0',
 'terminaltables>=3.1.0,<4.0.0']

entry_points = \
{'console_scripts': ['odhg = odherogrid.odhg:main']}

setup_kwargs = {
    'name': 'odherogrid',
    'version': '0.2.0',
    'description': 'Dota 2 hero grid generator using OpenDotaAPI stats',
    'long_description': '# ODHeroGrid\n\n\nSmall script that generates a custom Dota 2 Hero Grid layout of heroes sorted \nby winrate in public or professional games, using stats from OpenDota.\n\n\n# Installation\n```\npip install odherogrid\n```\n\n\n# Usage\n```\nUsage:\n  odhg [OPTIONS]\n\nOptions:\n  [-b, --brackets] BRACKET (default: 7)\n    Which skill bracket to get winrates from.\n      <1, herald, h>                          Herald\n      <2, guardian, g>                        Guardian\n      <3, crusader, c>                        Crusader\n      <4, archon, a>                          Archon\n      <5, legend, l>                          Legend\n      <6, ancient, n>                         Ancient\n      <7, divine, d>                          Divine\n      <8, pro, p>                             Pro\n      <0, all, A>                             All\n    Hero grids for multiple brackets can be generated by specifying the -b option several times.\n\n  [-l, --layout] LAYOUT (default: 1)\n    Which Hero Grid layout to use.\n      <1, mainstat, m>                        Mainstat\n      <2, attack, a>                          Attack\n      <3, role, r>                            Role\n      <0, single, s>                          Single\n\n  [-p, --path] PATH\n    Specify absolute path of Dota 2 userdata/cfg directory.\n    (It\'s usually better to run --setup to configure this path.)\n\n  [-s, --sort] (flag)\n    Sort heroes by winrate in ascending order. (Default: descending).\n\n  [-S, --setup] (flag)\n    Runs first-time setup in order to create a persistent config.\n\n  [-n, --name] NAME\n    Sort heroes by winrate in an existing custom hero grid. This option is ONLY for sorting hand-made grids. Grids generated by ODHG do not require this option.\n\n  [-h, --help] (flag)\n    Show this message and exit.\n\n  [-q, --quiet] (flag)\n    Suppress all terminal output except errors.\n\n```\n## Using standard configuration \n```\nodhg\n```\nPrompts to create config file in `~/.odhg/` the first time the program runs.\n\nThis is the recommended way to run ODHG.\n\n# Command-line options\nCommand-line options can be supplied to override config settings.\n\n\n## Bracket\n\n\n#### Create grid for Herald hero winrates:\n```\nodhg --brackets 1\n```\n\n\n#### Bracket names can also be used:\n```\nodhg --brackets herald\n```\n\n\n#### Shorter:\n```\nodhg -b h\n```\n\n\n#\n#### Create grids for Herald, Divine & Pro winrates:\n```\nodhg -b 1 -b 7 -b 8\n```\n\n#### Alternatively:\n```\nodhg -b h -b d -b p\n```\n\n\n#\n#### Create grids for all brackets:\n```\nodhg -b 0\n```\n\n\n## Layout\n#### Use role layout (Carry/Support/Flex). \n```\nodhg --layout role\n```\n\n#### Single category layout\n```\nodhg --layout single\n```\n\n\n## Path\n#### Specify a specific Steam user CFG directory:\n```\nodhg --path /home/bob/Steam/userdata/420666/570/remote/cfg\n```\n\n\n\n# Changelog\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\n\n## 0.2.0 (February XXth, 2020)\n### Added\n- Attempt to adhere to [Semantic Versioning](http://semver.org/)\n- `--quiet` option to suppress stdout. Errors are still displayed.\n- Printing of program progress ("Fetching data", "generating grids", etc.).\n- Printing of ASCII table displaying generated grids upon program completion.\n\n### Changed\n- Parameter `--grouping` renamed to `--layout`.\n- Layout `none` renamed to `single`.\n- Large parts of the program have been rewritten, but user experience should be identical.\n- Logo has received a small facelift.\n\n## 0.1.2 (January 24th, 2020)\n### Added\n- Sorting of specific custom grids by using the `--name` parameter\n\n### Changed\n- ~/.odhg/config.yml now lists full path of hero_grid_config.json instead of just its directory.',
    'author': 'PederHA',
    'author_email': 'peder.andresen@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/PederHA/odherogrid',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
